##############################
LinearOptimalPowerFlow class
##############################

.. |br| raw:: html

   <br />

Linear optimal power flow components are transmission components which additionally consider linear optimal power
flow equations.

**LinearOptimalPowerFlow class description:**

.. automodule:: lopf
.. autoclass:: LinearOptimalPowerFlow
   :members:
   :member-order: bysource

   .. automethod:: __init__

*Inheritance diagram:*

.. inheritance-diagram:: LinearOptimalPowerFlow
   :parts: 1

|

**LOPFModel class description:**

.. autoclass:: LOPFModel
   :members:
   :member-order: bysource

*Inheritance diagram:*

.. inheritance-diagram:: LOPFModel
   :parts: 1

